<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
################################################################################

include("../include/irm.inc");
require_once 'lib/Config.php';

AuthCheck("tech");
$templname = htmlspecialchars($templname);
$contents = htmlspecialchars($contents);
$solution = htmlspecialchars($solution);
$vals = array(
	'name' => $templname,
	'priority' => $priority,
	'request' => $contents,
	'response' => $solution
	);
$DB = Config::Database();
$DB->InsertQuery('fasttracktemplates', $vals);

header("Location: ".appendURLArguments($_SESSION['_sess_prevpage'], array('add' => 1)));
